==> nextcloud-app-mail-1.1.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/mn.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "шуудан",
    "Creating account failed: " : "аккаунт үүсгэж чадсангүй:",
    "Name" : "нэр",
    "Mail Address" : "шуудангийн хаяг",
    "Password" : "нууц үг",
    "None" : "юу ч үгүй",
    "IMAP Port" : "интернет мессеж хандалтын протокол -ийн порт",
    "IMAP User" : "интернет мессеж хандалтын протокол -ийн хэрэглэгч",
    "IMAP Password" : "интернет мессеж хандалтын протокол -ийн нууц үг",
    "SMTP Host" : "Энгийн мэйл дамжуулах протокол-ийн хост",
    "SMTP Port" : "Энгийн мэйл дамжуулах протокол-ийн порт",
    "SMTP User" : "Энгийн мэйл дамжуулах протокол-ийн хэрэглэгч",
    "SMTP Password" : "Энгийн мэйл дамжуулах протокол-ийн нууц үг",
    "Save" : "Хадгалах",
    "Connect" : "холбох",
    "Add mail account" : "шуудангийн хаяг нэмэх",
    "Select account" : "Аккаунт сонгох",
    "Subject" : "Сэдэв",
    "Add attachment from Files" : "Файлаас хавсралт нэмэх",
    "Sending …" : "илгээмж",
    "Go back" : "Буцах",
    "Retry" : "Дахин оролдох",
    "Message sent!" : "зурвас илгээсэн",
    "Send" : "илгээх",
    "Delete" : "Устгах",
    "Reply" : "хариулт",
    "Forward" : "дамжих",
    "Download attachment" : "Татаж авах хавсралт",
    "Save to Files" : "Файлд хадгална",
    "Choose a folder to store the attachment in" : "-д хавсралт хадгалах фолдер сонгоно уу",
    "Save all to Files" : "бүх файлыг хадгалах",
    "The images have been blocked to protect your privacy." : " таны хувийн нууцыг хамгаалахын тулд дүрсийг хаасан байна.",
    "New message" : "шинэ зурвас",
    "Settings" : "тохиргоо",
    "Add folder" : "Add folder",
    "Delete account" : "аккаунтыг устгах",
    "Show all folders" : "Бүх хавтас харуулах",
    "Signature" : "Гарын үсэг",
    "General" : "Ерөнхий",
    "User" : "Хэрэглэгч",
    "Host" : "хост",
    "Port" : "порт",
    "Search" : "Хайх",
    "Refresh" : "Сэргээх",
    "Connect your mail account" : "Таны мэйл бүртгэлийг холбоно",
    "Error loading message" : "алдаатай ачааллах зурвас"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-3.5.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/mn.js <==
OC.L10N.register(
    "mail",
    {
    "Work" : "Ажил",
    "Personal" : "Хувийн",
    "Later" : "Хойшлуулах",
    "Mail" : "шуудан",
    "Name" : "нэр",
    "Mail address" : "шуудангийн хаяг",
    "Password" : "нууц үг",
    "None" : "юу ч үгүй",
    "IMAP Port" : "интернет мессеж хандалтын протокол -ийн порт",
    "IMAP User" : "интернет мессеж хандалтын протокол -ийн хэрэглэгч",
    "IMAP Password" : "интернет мессеж хандалтын протокол -ийн нууц үг",
    "SMTP Host" : "Энгийн мэйл дамжуулах протокол-ийн хост",
    "SMTP Port" : "Энгийн мэйл дамжуулах протокол-ийн порт",
    "SMTP User" : "Энгийн мэйл дамжуулах протокол-ийн хэрэглэгч",
    "SMTP Password" : "Энгийн мэйл дамжуулах протокол-ийн нууц үг",
    "Connecting" : "холбож байгаа",
    "Save" : "Хадгалах",
    "Connect" : "холбох",
    "Signature" : "Гарын үсэг",
    "Go back" : "Буцах",
    "Cancel" : "болиулах",
    "Add mail account" : "шуудангийн хаяг нэмэх",
    "Select account" : "Аккаунт сонгох",
    "Subject" : "Сэдэв",
    "Add attachment from Files" : "Файлаас хавсралт нэмэх",
    "Send" : "илгээх",
    "Confirm" : "Батлах",
    "Favorite" : "Дуртай",
    "Select" : "Сонгох",
    "Back" : "буцах",
    "Forward" : "дамжих",
    "Create" : "Үүсгэх",
    "Comment" : "undefined",
    "Accept" : "Хүлээн зөвшөөрөх",
    "Decline" : "Зөвшөөрөхгүй",
    "Choose" : "Сонгох",
    "Other" : "Бусад",
    "Reply" : "хариулт",
    "Download attachment" : "Татаж авах хавсралт",
    "Save to Files" : "Файлд хадгална",
    "Choose a folder to store the attachment in" : "-д хавсралт хадгалах фолдер сонгоно уу",
    "Save all to Files" : "бүх файлыг хадгалах",
    "The images have been blocked to protect your privacy." : " таны хувийн нууцыг хамгаалахын тулд дүрсийг хаасан байна.",
    "Move" : "Зөөх",
    "Quota" : " хувь хэмжээ",
    "Saving" : "хадгаламж",
    "Remove account" : "Аккаунт устгах",
    "Loading …" : "Уншиж байна...",
    "New message" : "шинэ зурвас",
    "Refresh" : "Сэргээх",
    "Retry" : "Дахин оролдох",
    "Sending …" : "илгээмж",
    "Delete" : "Устгах",
    "Add" : "нэмэх",
    "Tags" : "Tag-үүд",
    "Search" : "Хайх",
    "Date" : "Он сар өдөр",
    "Disabled" : "идэвхигүй",
    "Enabled" : "Идэвхижүүлэх",
    "Custom" : "Дурын",
    "Remove" : "Устгах",
    "Reset" : "тохируулах",
    "Client ID" : "Хэрэглэгчийн ID",
    "General" : "Ерөнхий",
    "User" : "Хэрэглэгч",
    "Host" : "хост",
    "Port" : "порт",
    "Certificate" : "Гэрчилгээ",
    "Submit" : "мэдэгдэх",
    "Keyboard shortcut" : "Keyboard товчлуур",
    "Archive" : "архив",
    "Connect your mail account" : "Таны мэйл бүртгэлийг холбоно",
    "All" : "бүх",
    "Drafts" : "ноорог",
    "Favorites" : "Онцолсон",
    "Inbox" : "ирсэн",
    "Junk" : "хэрэггүй",
    "Sent" : "илгээсэн",
    "Trash" : "хог",
    "Error loading message" : "алдаатай ачааллах зурвас"
},
"nplurals=2; plural=(n != 1);");
